﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Diagnostics;
using Infragistics.Controls.Charts;
using System.Threading;
using Infragistics.Windows;
using System.Text;
using System.Windows;
using System.Windows.Controls;

public partial class MainWindow : Window
{
	public MainWindow()
	{
		InitializeComponent();
		BuildGraph(ref fcMainChart);
	}

	public void BuildGraph(ref XamDataChart DataChart)
	{
		string CurCulture = null;
		CurCulture = System.Threading.Thread.CurrentThread.CurrentCulture.ToString();

		DataChart.Series.Clear();

		for (int i = 0; i <= 2; i++)
		{
			DataTable table = CreateTable(10);
			dynamic data = from row in table.AsEnumerable()
						   select new DateDataItem
						   {
							   Date = Convert.ToDateTime(row["Date"]),
							   Value1 = Convert.ToDouble(row["MAPE"])
						   };

			LineSeries lSeries = new LineSeries();
			MainXAxis.DateTimeMemberPath = "Date";
			lSeries.XAxis = MainXAxis;
			lSeries.YAxis = MainYAxis;
			lSeries.Title = "Series " + i;
			lSeries.Legend = TitleLegend;
			lSeries.ItemsSource = data;
			lSeries.ValueMemberPath = "Value1";

			lSeries.LegendItemTemplate = this.Resources["legendItemTemplate"] as DataTemplate;
			lSeries.LegendItemBadgeTemplate = this.Resources["legendItemBadgeTemplate"] as DataTemplate;

			System.DateTime minVal = (DateTime)table.Rows[0].ItemArray[0];
			System.DateTime maxVal = (DateTime)table.Rows[table.Rows.Count - 1].ItemArray[0];
			TimeSpan axisRange = maxVal - minVal;

			var _with1 = MainXAxis;
			_with1.DataContext = data;
			_with1.MinimumValue = minVal;
			_with1.MaximumValue = maxVal;
			_with1.LabelSettings.Angle = 45;
			_with1.Label = "{Date:T}";

			fcMainChart.Series.Add(lSeries);
		}
	}

	public DataTable CreateTable(int rows)
	{
		DataTable d = new DataTable();
		Random r = new Random();

		//Just to get three different random lines - otherwise series 1 & 2 match
		Thread.Sleep(100);


		System.DateTime tDate = DateTime.Now;
		d.Columns.Add(new DataColumn("Date", typeof(DateTime)));
		d.Columns.Add(new DataColumn("MAPE", typeof(int)));


		for (int i = 0; i <= rows; i++)
		{
			DataRow row = d.NewRow();

			row["Date"] = tDate.AddHours(i);
			row["MAPE"] = r.Next(1000 * i);
			d.Rows.Add(row);
		}

		return d;
	}

	private void LineSeries1VisibilityClick(System.Object sender, System.Windows.RoutedEventArgs e)
	{
		CheckBox chb = sender as CheckBox;
		if (chb != null && chb.IsChecked != null)
		{
			fcMainChart.Series[(int)chb.Tag].Opacity = chb.IsChecked.Value ? 1 : 0;
		}
	}

	private void Button_Click_1(object sender, RoutedEventArgs e)
	{
		StringBuilder result = new StringBuilder();
		foreach (var item_loopVariable in TitleLegend.Children)
		{
			var item = item_loopVariable;
			CheckBox checkBox = Utilities.GetDescendantFromType(item, typeof(CheckBox), true) as CheckBox;
			result.AppendLine("CheckBox" + checkBox.Tag.ToString() + ":" + checkBox.IsChecked.ToString());
		}
		MessageBox.Show(result.ToString());
	}
}

public class DateDataItem
{
	public System.DateTime Date
	{
		get { return m_Date; }
		set { m_Date = value; }
	}
	private System.DateTime m_Date;
	public double Value1
	{
		get { return m_Value1; }
		set { m_Value1 = value; }
	}

	private double m_Value1;
}
